# Igor helpers

This directory contains various servers and utilities
that are primarily helpers for Igor.

## bleServer

A service that listens to Bluetooth-LE advertisements. Works together with the Igor _ble_ plugin to detect availability of mobile devices (and can thereby determine whether the owners of those devices are at home).

Tested only on Raspberry PI with Broadcom BCM20702A0 USB dongle.

## kaku

Utility to control KlikAanKlikUit electrical switches.

